@@ -40,10 +40,15 @@ class Chord(NoteSet):
     root: Note
     name: str
 
+    def __init__(self, notes: frozenset[str | Note], *, root: str | Note):
+        if root is None:
+            raise TypeError('Chord requires root note. Use NoteSet if there is no root')
+        super().__init__(notes, root=root)
+
     def _repr_html_(self) -> str:
         return f"""
         <div class='{' '.join(self.html_classes)}'>
-        <span class='card_header'><h3>{self.root.name} {self.name}</h3></span>
+        <h3 class='card_header'>{self.root.name} {self.name}</h3>
         {self.to_piano_image()}
         </div>
         """
@@ -164,5 +169,23 @@ class SpecificChord(Cached):
         mid.save(path)
         return None
 
+    def to_piano_image(self) -> str:
+        from musictool.noterange import NoteRange
+        from musictool.piano import Piano
+        noterange = NoteRange(self[0], self[-1]) if self.notes else None
+        return Piano(
+            note_colors=dict.fromkeys(self.notes, config.RED),
+            squares={note: {'text': str(note), 'text_size': '8'} for note in self},
+            noterange=noterange,
+        )._repr_svg_()
+
+    def _repr_html_(self) -> str:
+        return f"""
+        <div class='specificchord'>
+        <h3 class='card_header'>{self}</h3>
+        {self.to_piano_image()}
+        </div>
+        """
+
     def __getnewargs_ex__(self):
         return (self.notes,), {'root': self.root}
